#
# spec file for package python-widgetsnbextension
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define jupver 8.0.13
Name:           python-widgetsnbextension
Version:        4.0.13
Release:        1.1
Summary:        Jupyter interactive widgets for Jupyter Notebook
License:        BSD-3-Clause AND MIT
URL:            https://github.com/jupyter-widgets/ipywidgets/tree/master/python/widgetsnbextension
Source:         https://files.pythonhosted.org/packages/source/w/widgetsnbextension/widgetsnbextension-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module jupyter-packaging}
BuildRequires:  %{python_module nbclassic}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  jupyter-rpm-macros
BuildRequires:  python-rpm-macros
Requires:       jupyter-widgetsnbextension = %{version}
Provides:       python-jupyter_widgetsnbextension = %{version}-%{release}
Obsoletes:      python-jupyter_widgetsnbextension < %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
This package makes Jupyter widgets available in the classic Jupyter Notebook.
This package provides the necessary JavaScript controls in the Jupyter
Notebook that communicate with the widget objects in the kernel.

Install the corresponding Jupyter widgets package into your kernel, i.e.,
IPython users would install ipywidgets into their kernel.

%package -n jupyter-widgetsnbextension
Summary:        Jupyter interactive widgets for Jupyter Notebook - Jupyter Files
Requires:       (jupyter-notebook < 7 or jupyter-nbclassic)
Requires:       python3dist(widgetsnbextension) = %{version}
Suggests:       python3-widgetsnbextension
Provides:       jupyter-jupyter-js-widgets = %{jupver}
Provides:       jupyter-jupyter-jupyter-widgets-notebook-manager = %{jupver}

%description  -n jupyter-widgetsnbextension
This package makes Jupyter widgets available in the classic Jupyter Notebook.
It provides the Jupyter configuration files.

%prep
%setup -q -n widgetsnbextension-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export JUPYTER_PATH=%{buildroot}%{_jupyter_prefix}
export JUPYTER_CONFIG_DIR=%{buildroot}%{_jupyter_confdir}
%{python_expand # no $python tests available
export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -c 'import widgetsnbextension'
jupyter-%{$python_bin_suffix} nbclassic-extension list 2>&1 | grep 'jupyter-js-widgets.*enabled'
}
rm -f %{buildroot}%{_jupyter_confdir}migrated

%files %{python_files}
%license LICENSE
%{python_sitelib}/widgetsnbextension
%{python_sitelib}/widgetsnbextension-%{version}*-info

%files -n jupyter-widgetsnbextension
%license LICENSE
%{_jupyter_config} %{_jupyter_nb_notebook_confdir}/widgetsnbextension.json
%dir %{_jupyter_nbextension_dir}/jupyter-js-widgets
%{_jupyter_nbextension_dir}/jupyter-js-widgets/extension.js
%{_jupyter_nbextension_dir}/jupyter-js-widgets/extension.js.LICENSE.txt
%{_jupyter_nbextension_dir}/jupyter-js-widgets/extension.js.map

%changelog
* Sun Sep 15 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.0.13
  [#] release notes from ipywidgets 8.1.4 and 8.1.3
  * More Phosphor backward compatibility by @martinRenou in #3942
  [#]# New features
  * Allow interact to use basic type hint annotations by
    @corranwebster in #3908
  * Support horizontal orientation of radio buttons by
    @DonJayamanne in #3620
  [#]# Maintenance and bug fixes
  * Fix compatibility with pytest 8 by @frenzymadness in #3903
  * HTMLManager: Support both ipywidgets 7 and 8 models by
    @martinRenou in #3932
  * Make tests compatible with Python 3.13 by @frenzymadness in
    [#3924]
  * fix: get_metadata deprecated since traitlets 4.1 by
    @ManonMarchand in #3894
  * Phosphor widget backward compatibility fixes by @martinRenou in
    [#3933]
  * Remove confusing error message by @martinRenou in #3936
  * Fix wrong tag index in TagsInput when updated via python by
    @s-weigand in #3862
* Fri Jul 12 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.0.11
  * Add support for widgets in JupyterLab code consoles by @jtpio
    in #3004
  * Add return to pack_models by @gjmooney in #3923
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 4.0.10 with jupyter-js-widgets 8.0.10
  * Bump systeminformation from 5.18.3 to 5.21.8 in /ui-tests by
    @dependabot in #3837
  * Try to use manager's latexTypesetter if window.MathJax is not
    defined by @bollwyvl in #3847
  * fix: restoring widgets from saved state is broken since v8 in
    Lab by @mariobuikhuizen in #3866
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19 (through
  nbclassic)
* Sun Sep 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 4.0.9 with jupyter-js-widgets 8.0.9
  * no own release notes, see ipywidgets 8.1.1: Raise error when
    copy method is used on base widget class by @mmc1718 in #3780
* Sat Aug 26 2023 Ben Greiner <code@bnavigator.de>
- Avoid notebook 7: use nbclassic or notebook < 6
* Fri Aug 18 2023 Ben Greiner <code@bnavigator.de>
- Update to 4.0.8
  * no own release notes, see ipywidgets 8.1:
  - Allow CSS variables to be used as values in the Color trait
    by @nurbo in #3796
- Update requirements of python for js files to work: any python
  is okay
* Tue Apr  4 2023 Ben Greiner <code@bnavigator.de>
- Update to 4.0.7
  [#]# release notes from ipywidgets 8.0.6
  * Fix: revert removing ipykernel dependency #3749
  * Fix: structuredClone broke default serializer that depended on
    JSON/toJSON #3738
  * Fix: comm/ipykernel/manager runtime issues: #3740, #3737
  * Fix: propertly typed Comm interface #3722
  * Fix: support the comm package #3533
  * Fix: use of structuredClone allows for binary traits out of the
    box #3689
  * Fix: combobox update issue #3681
  * Fix: add grey as valid color #3671
  * Fix: deprecation warning when using interact #3669
* Sun Jan  8 2023 Ben Greiner <code@bnavigator.de>
- Update to 4.0.5 with jupyter-js-widgets 8.0.5
  * no release notes
  * js package version bumps
- PEP517 jupyter-packaging build
* Thu Sep  8 2022 Arun Persaud <arun@gmx.de>
- update to version 4.0.3:
  * no release notes
* Sat Aug 20 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * require python >= 3.7
  * require jupyter-packaging
  * added js license file
- update to version 4.0.2 with jupyter-js-widgets@8.0.2
  * no relase notes
* Wed Aug  3 2022 Ben Greiner <code@bnavigator.de>
- Update to 3.6.1
  * no release notes (JS static version bumps)
* Sat Mar 26 2022 Ben Greiner <code@bnavigator.de>
- Update to 3.6.0
  * no release notes
* Sun Oct 31 2021 Ben Greiner <code@bnavigator.de>
- Update to 3.5.2
  * no release notes
  * bundled JS package updates
* Fri Oct 29 2021 Ben Greiner <code@bnavigator.de>
- Bump release in order to facilitate removal of
  jupyter-widgetsnbextension source package
- Provide/Obsolete old python-jupyter_widgetsnbextension name
* Sun Oct 17 2021 Ben Greiner <code@bnavigator.de>
- initial specfile for 3.5.1
- Required by ipywidgets
